@@ -1,8 +1,7 @@
 import os
-from pathlib import Path
+import subprocess
 
 from ... import paths
-from ..conda_env import run_in_env
 
 
 def tarball(options=""):
@@ -11,9 +10,9 @@ def tarball(options=""):
     Args:
         options (str, optional): Additional options to pass to Snakemake.
     """
-    snakefile = snakefile = Path("${SYW_PATH}") / "workflow" / "build.smk"
-    snakemake = f"SNAKEMAKE_OUTPUT_CACHE={paths.user().cache} SNAKEMAKE_RUN_TYPE='tarball' snakemake -c1 --use-conda --reason --cache"
+    snakefile = paths.showyourwork().workflow / "build.smk"
+    snakemake = f"SNAKEMAKE_OUTPUT_CACHE={paths.user().cache} SNAKEMAKE_RUN_TYPE='tarball' snakemake -c1 --use-conda --conda-frontend conda --reason --cache"
     command = f"{snakemake} {options} -s {snakefile} syw__arxiv_entrypoint"
-    result = run_in_env(command, check=False)
+    result = subprocess.run(command, shell=True, check=False)
     if result.returncode > 0:
         os._exit(1)
