@@ -122,7 +122,7 @@ def clone(project_id, path=None):
     # Overleaf uses a branch called 'master' by default. If the local config
     # uses a different name, we need to change it.
     get_stdout(
-        ["git", "branch", "-M", "master"],
+        ["git", "checkout", "-b", "master"],
         cwd=str(paths.user(path=path).overleaf),
     )
 
@@ -157,7 +157,7 @@ def wipe_remote(project_id):
     """
     with TemporaryDirectory() as cwd:
         get_stdout(["git", "init"], cwd=cwd)
-        get_stdout(["git", "branch", "-M", "master"], cwd=cwd)
+        get_stdout(["git", "checkout", "-b", "master"], cwd=cwd)
         (
             overleaf_email,
             overleaf_password,
@@ -380,7 +380,7 @@ def push_files(files, project_id, path=None):
     # Remove missing files from the list
     if skip:
         skip_list = " ".join([str(s) for s in skip])
-        logger.warn(f"Skipping missing file(s): {skip_list}")
+        logger.warning(f"Skipping missing file(s): {skip_list}")
         files = list(set(files) - set(skip))
 
     # Commit callback
@@ -394,7 +394,9 @@ def push_files(files, project_id, path=None):
                 or "nothing to commit" in stdout + stderr
                 or "nothing added to commit" in stdout + stderr
             ):
-                logger.warn(f"No changes to commit to Overleaf: {file_list}")
+                logger.warning(
+                    f"No changes to commit to Overleaf: {file_list}"
+                )
             else:
                 raise exceptions.CalledProcessError(stdout + "\n" + stderr)
         else:
@@ -433,6 +435,8 @@ def pull_files(
     error_if_missing=False,
     error_if_local_changes=False,
     path=None,
+    commit_changes=True,
+    push_changes=False,
 ):
     """
     Pull files from the Overleaf remote.
@@ -448,6 +452,11 @@ def pull_files(
             prints a warning but does not interrupt the workflow.
         path (str, optional): The path to the top level of the user's repo
             (if running from a different directory).
+        commit_changes (bool, optional): Commit changes to the article
+            repository? Default ``True``.
+        push_changes (bool, optional): Push committed changes to the remote article
+            repository? Only applicable if ``commit_changes`` is ``True``.
+            Default ``False``.
 
     """
     # Disable if user didn't specify an id or if there are no files
@@ -557,32 +566,40 @@ def pull_files(
 
             get_stdout(["diff", remote_file, file], callback=callback)
 
-    def callback(code, stdout, stderr):
-        if code == 0:
-            logger.info(
-                "Overleaf changes committed to the repo. Don't forget to push!"
-            )
-        else:
-            if (
-                "Your branch is up to date" in stdout + stderr
-                or "nothing to commit" in stdout + stderr
-                or "nothing added to commit" in stdout + stderr
-            ):
-                logger.warn(f"No Overleaf changes to commit to the repo.")
-            else:
-                raise exceptions.CalledProcessError(stdout + "\n" + stderr)
+    if commit_changes:
 
-    get_stdout(
-        [
-            "git",
-            "-c",
-            "user.name='showyourwork'",
-            "-c",
-            "user.email='showyourwork'",
-            "commit",
-            "-m",
-            "[showyourwork] overleaf sync",
-        ],
-        cwd=paths.user(path=path).repo,
-        callback=callback,
-    )
+        def callback(code, stdout, stderr):
+            if code == 0:
+                logger.info(
+                    "Overleaf changes committed to the repo. Don't forget to push!"
+                )
+            else:
+                if (
+                    "Your branch is up to date" in stdout + stderr
+                    or "nothing to commit" in stdout + stderr
+                    or "nothing added to commit" in stdout + stderr
+                ):
+                    logger.warning(
+                        f"No Overleaf changes to commit to the repo."
+                    )
+                else:
+                    raise exceptions.CalledProcessError(stdout + "\n" + stderr)
+
+        get_stdout(
+            [
+                "git",
+                "-c",
+                "user.name='showyourwork'",
+                "-c",
+                "user.email='showyourwork'",
+                "commit",
+                "-m",
+                "[showyourwork] overleaf sync",
+            ],
+            cwd=paths.user(path=path).repo,
+            callback=callback,
+        )
+
+        if push_changes:
+
+            get_stdout(["git", "push"], cwd=paths.user(path=path).repo)
