@@ -27,6 +27,16 @@ def is_relative_to(path, other):
         return False
 
 
+def removeprefix(s, prefix):
+    """
+    Local implementation of `str.removeprefix` (for python < 3.9).
+
+    """
+    if s.startswith(prefix):
+        s = s[len(prefix) :]
+    return s
+
+
 # Convert to PNG & get aspect ratio
 def convert_to_png(file):
     """
@@ -92,24 +102,43 @@ if __name__ == "__main__":
     )
 
     # Collect all dependency information
-    dependencies = config["dag_dependencies"]
+    deps = config["dag_dependencies"]
+    prefix = str(paths.user().repo / "x")[:-1]
+    dependencies = {}
+    for f, d in deps.items():
+        dependencies[removeprefix(f, prefix)] = [
+            removeprefix(file, prefix) for file in d
+        ]
 
     # Ignore temporary & showyourwork files
     ignore = config["tex_files_out"] + [
         config["stylesheet"],
         config["stylesheet_meta_file"],
-        str(paths.user().flags / "SYW__DAG"),
-        str(paths.user().flags / "SYW__CONDA"),
-        str(paths.user().compile),
+        str((paths.user().flags / "SYW__DAG").relative_to(paths.user().repo)),
+        str(
+            (paths.user().flags / "SYW__CONDA").relative_to(paths.user().repo)
+        ),
+        str(paths.user().compile.relative_to(paths.user().repo)),
         "dag.pdf",
         "showyourwork.yml",
+        "zenodo.yml",
     ]
 
+    # Ignore user-specified patterns
+    user_ignore = []
+    for pat in config["dag"]["ignore_files"]:
+        file_list = list(Path(paths.user().repo).glob(pat))
+        file_list = [
+            str(file.relative_to(paths.user().repo)) for file in file_list
+        ]
+        user_ignore.extend(file_list)
+    ignore.extend(user_ignore)
+
     # Assemble all files
     files = []
-    for file in config["dag_dependencies"]:
+    for file in dependencies:
         files.append(file)
-        files.extend(config["dag_dependencies"][file])
+        files.extend(dependencies[file])
     files = list(set(files))
     files = [file for file in files if file not in ignore]
 
@@ -135,7 +164,10 @@ if __name__ == "__main__":
 
     # Get permalink for file
     def file2url(file):
-        return f"{config['git_url']}/blob/{config['git_sha']}/{file}"
+        if file.startswith("src/tex/output/"):
+            return None
+        else:
+            return f"{config['git_url']}/blob/{config['git_sha']}/{file}"
 
     # Zenodo nodes
     with dot.subgraph(name=f"{subgraph_prefix}zenodo") as c:
@@ -178,7 +210,7 @@ if __name__ == "__main__":
             label="src/data/",
         )
         for file in datasets:
-            label = file.removeprefix("src/data/")
+            label = removeprefix(file, "src/data/")
             c.node(
                 file,
                 label=label,
@@ -198,7 +230,7 @@ if __name__ == "__main__":
             label="src/scripts/",
         )
         for file in scripts:
-            label = file.removeprefix("src/scripts/")
+            label = removeprefix(file, "src/scripts/")
             c.node(
                 file,
                 label=label,
@@ -217,7 +249,7 @@ if __name__ == "__main__":
             label="src/tex/",
         )
         for file in texfiles:
-            label = file.removeprefix("src/tex/")
+            label = removeprefix(file, "src/tex/")
             c.node(
                 file,
                 label=label,
@@ -253,7 +285,7 @@ if __name__ == "__main__":
                 )
             else:
                 # Couldn't convert to PNG; display text instead
-                label = file.removeprefix("src/data/")
+                label = removeprefix(file, "src/data/")
                 c.node(
                     file,
                     label=label,
