@@ -1,8 +1,11 @@
+import os
 import shutil
 from pathlib import Path
 
 import pytest
 
+from showyourwork.git import get_repo_sha
+
 
 def pytest_sessionstart(session):
     # Clean the sandbox
@@ -19,12 +22,19 @@ def pytest_addoption(parser):
         default=False,
         help="enable remote tests",
     )
+    parser.addoption(
+        "--action-spec",
+        action="store",
+        default="showyourwork",
+        help="version spec of showyourwork to install on GH Actions",
+    )
 
 
 def pytest_configure(config):
     config.addinivalue_line(
         "markers", "remote: a test that requires remote access"
     )
+    os.environ["ACTION_SPEC"] = str(config.getoption("--action-spec"))
 
 
 def pytest_collection_modifyitems(config, items):
